import React from "react";
interface FileUploadConfig {
    chunkSize?: number;
    resumable?: boolean;
    encryption?: boolean;
}
interface FileState {
    id: string;
    file: File;
    state: {
        status: "pending" | "uploading" | "paused" | "completed" | "error" | "cancelled" | "restarted" | "idle";
        progress: number;
        errors: string[];
        uploadedBytes?: number;
    };
    metadata?: Record<string, any>;
}
interface UseUploadProps {
    id?: string;
    action: string;
    globalConfig?: {
        maxConcurrentUploads?: number;
        maxFiles?: number;
        mode?: "single" | "multiple";
        maxFileSize?: number;
        allowedFileTypes?: string[];
    };
    uploadConfig?: FileUploadConfig;
    metadata?: Record<string, any>;
    onUploadStart?: (files: FileState[]) => void;
    onUploadProgress?: (file: FileState) => void;
    onUploadComplete?: (response: Response, file: FileState) => void;
    onError?: (error: Error, file: FileState) => void;
    headers?: Record<string, string>;
}
export declare const useUpload: ({ id, action, globalConfig, metadata, onUploadStart, onUploadComplete, onError, headers, }: UseUploadProps) => {
    acceptedFiles: FileState[];
    errors: string[];
    getRootProps: () => {
        onDrop: (event: React.DragEvent<HTMLDivElement>) => void;
        onClick: () => void;
    };
    getInputProps: () => {
        type: string;
        multiple: boolean;
        accept: string;
        max: string;
        onChange: (e: React.ChangeEvent<HTMLInputElement>) => void;
    };
    removeFile: (fileId: string) => void;
    uploadFile: (fileId: string) => Promise<Response | undefined>;
    restartUpload: (fileId: string) => void;
};
export {};
